
# Script for "Why Parties Take up Digitization in their Manifestos"

# Authors: Pascal Knig and Georg Wenzelburger
# Version date: 26 October 2018



#### required packages ####

library(interplot)
library(car)
library(pastecs)
library(sandwich)
library(lmtest)



rm(list = ls()) # clear object space


#### read data file ####

df <- read.csv2(file = "Replication material - Dataset digitization.csv", 
                sep = ",", dec = ".",
                encoding= "UTF-8") 



#### prepare dataset ####

### recode variables ###

df$election <- paste(df$Country,df$Year, sep = " ") # generate election variable
df$Party_size <- df$Party_size/100



### Generate z-score scaled dependent variable ###

tmp <- aggregate(df$Issue.emphasis, by =list(df$election), mean)
colnames(tmp) <- c("election", "mean")
df <- merge(df, tmp)
tmp <- aggregate(df$Issue.emphasis, by =list(df$election), sd)
colnames(tmp) <- c("election", "sd")
df <- merge(df, tmp)


df$Z_issue.emphasis <- (df$Issue.emphasis - df$mean)/df$sd







#### Descriptives: Country-wise mean and SD ####

df_descr <- df

df_descr <- df_descr[order(df_descr$Country, df_descr$issue.emphasis_demeaned) , ]
df_descr$ID <- paste(df_descr$Party, "", df_descr$Year)
df_descr$ID <- factor(df_descr$ID, levels = df_descr$ID[ order(df_descr$Country, df_descr$Issue.emphasis) ] )
df_descr$election <- paste(df_descr$Country,df_descr$Year, sep = " ") # generate election variable

# Calculation of mean and sd of each group
my_mean=aggregate(df_descr$Issue.emphasis , by=list(df_descr$election) , mean) ; colnames(my_mean)=c("names" , "mean")
my_sd=aggregate(df_descr$Issue.emphasis , by=list(df_descr$election) , sd) ; colnames(my_sd)=c("names" , "sd")
my_info=merge(my_mean , my_sd , by.x=1 , by.y=1)


my_year=aggregate(df_descr$Year , by=list(df_descr$election) , mean) ; colnames(my_year)=c("names" , "year")
my_info=merge(my_info , my_year , by.x=1 , by.y=1)

my_cntmean = aggregate(df_descr$Issue.emphasis , by=list(df_descr$Country) , mean) 
colnames(my_cntmean) = c("Country" , "cntmean")
my_info$Country <- c(rep("Austria", 2),
                     rep("France", 2),
                     rep("Germany", 2),
                     rep("Ireland", 2),
                     rep("Italy", 2),
                     rep("Portugal", 2),
                     rep("Spain", 2),
                     rep("United Kingdom", 3)
                     )

my_info = merge(my_info , my_cntmean)

df_descr <- merge(df_descr , my_cntmean)


# Make the plot

ggplot(df_descr) + 
  geom_errorbar(data = my_info, 
                aes(x=reorder(names, cntmean),  ymin = mean - sd, ymax = mean + sd), 
                colour = "grey45" , width = 0.5 , size=0.5) +  
  geom_point(aes(x = election, y = Issue.emphasis) , colour="grey50" , size=1.2) + 
  geom_point(data = my_info, 
             aes(x= reorder(names, cntmean) , y = mean) , 
             colour = "black" , size = 3,
             shape = 18) +
  coord_flip() +
  theme_light() + 
  theme(panel.grid.major.x = element_line(colour = "grey40")) +
  scale_y_continuous(breaks = c(0, 1, 2,  3,  4, 5, 6) ) +
  xlab("") +
  ylab("Emphasis on digitization")







#### Descriptives: Box plots for party families ####

# Demean DV
tmp <- aggregate(df_descr$Issue.emphasis, by =list(df_descr$election), mean)
colnames(tmp) <- c("election", "mean")
df_descr <- merge(df_descr, tmp)

df_descr$issue.emphasis_demean <- (df_descr$Issue.emphasis - df_descr$mean)


table(df_descr$Party.family) # check distribution of party families

df_descr$Party.family.new[df_descr$Party.family == 1  | df_descr$Party.family == 8] <- "Radical right"
df_descr$Party.family.new[df_descr$Party.family == 2 | df_descr$Party.family == 4] <- "Cons./Christ.Dem."
df_descr$Party.family.new[df_descr$Party.family == 3] <- "Liberal"
df_descr$Party.family.new[df_descr$Party.family == 5] <- "Soc. Dem./Socialist"
df_descr$Party.family.new[df_descr$Party.family == 6] <- "Radical left"
df_descr$Party.family.new[df_descr$Party.family == 7] <- "Green"
df_descr$Party.family.new[df_descr$Party.family == 9] <- "No fam./populist"

unique( df_descr$Party[df_descr$Party.family == 9] )

aggregate(df_descr$issue.emphasis_demean, by =list(df_descr$Party.family.new ), mean)

df_descr$Party.family.new <- as.factor(df_descr$Party.family.new)


# generate variable for party family means to reorder yaxis

party.fam_mean = aggregate(df_descr$issue.emphasis_demean , by=list(df_descr$Party.family.new) , mean)
colnames(party.fam_mean)=c("Party.family.new" , "party.fam_mean")
df_descr <- merge(df_descr, party.fam_mean)



# make the plot

ggplot(data = df_descr, aes(x= reorder(Party.family.new, party.fam_mean), y= issue.emphasis_demean) ) +  
  geom_boxplot()  + 
  xlab("Party family") +
  ylab("Emphasis on digitization (demeaned by election)") +
  coord_flip() + 
  theme_light() + 
  theme(axis.title.y=element_blank(), axis.text=element_text(size=12), axis.title =element_text(size=10)  ) 






### Descriptives Table ###

stat.desc(df)








#### Regression analysis ####


### Model 1: base model ###
reg_fit_fe1 <- lm(Issue.emphasis
               ~ Previous.government
               + Party_size
               + Prec.Vote.share.change.2
               + Challenger2
               + lrecon
               + galtan
               + factor(election),
               data = df)

summary(reg_fit_fe1)



# get robust standard errors 

m1_rob <- coeftest(reg_fit_fe1, vcov = vcovHC(reg_fit_fe1, type="HC1"))
print(m1_rob)


### Model with Z-scores for DV ###

reg_fit_Z1 <- lm(Z_issue.emphasis
                 ~ Previous.government
                 + Party_size
                 + Prec.Vote.share.change.2
                 + Challenger2
                 + lrecon
                 + galtan,
                 data = df)
summary(reg_fit_Z1)


# get robust standard errors 

m2_rob <- coeftest(reg_fit_Z1, vcov = vcovHC(reg_fit_Z1, type="HC1"))
print(m2_rob)




### Additional Model: lrecon*challenger ###
reg_fit_Z2 <- lm(Z_issue.emphasis
                ~ Previous.government
                + Party_size
                + Prec.Vote.share.change.2
                + Challenger2
                + lrecon
                + galtan
                + Challenger2*lrecon,
                data = df)
summary(reg_fit_Z2)


# Interaction plot (marginal effects)

interplot(m = reg_fit_Z2, var1 = "lrecon" , var2 = "Challenger2" , ci = 0.90) + 
  theme(axis.text=element_text(size=20), axis.title =element_text(size=20)  ) + 
  theme_light() + 
  geom_hline(yintercept=0) +
  labs(x = "Challenger status", y = "marginal effect Economic policy stance")




### Additional Model:  galtan*challenger ###
reg_fit_Z3 <- lm(Z_issue.emphasis
                ~ Previous.government
                + Party_size
                + Prec.Vote.share.change.2
                + Challenger2
                + lrecon
                + galtan
                + Challenger2*galtan,
                data = df)
summary(reg_fit_Z3)


# Interaction plot (marginal effects)

interplot(m = reg_fit_Z3, var1 = "galtan" , var2 = "Challenger2" , ci = 0.90) + 
  theme(axis.text=element_text(size=20), axis.title =element_text(size=20)  ) + 
  theme_light() + 
  geom_hline(yintercept=0) +
  labs(x = "Challenger status", y = "marginal effect of GAL-TAN stance")




#### Robustness checks ####

### Remove Influential Observations via Cook's D ###

reg_fit_full <- reg_fit_Z1

cutoff <- 4/((nrow(df)-length(reg_fit_full$coefficients)-2)) # calculate cut-off point

cooks.frame <- data.frame(df$Party, df$Year,cooks.distance(reg_fit_full) )

cooks.frame [order(abs(cooks.frame$cooks.distance.reg_fit_full. ) ), ]


cooks.frame[cooks.frame$cooks.distance.reg_fit_full. > cutoff, ]
rownames(cooks.frame[cooks.frame$cooks.distance.reg_fit_full. > cutoff, ])


plot(reg_fit_full, which=4, cook.levels=cutoff)


# Influence Plot
influencePlot(reg_fit_full, id.method="identify", 
              main="Influence Plot", 
              sub="Circle size  proportial to Cook's D" )




# Regression without influential cases
df2 <- df[rownames(cooks.frame[cooks.frame$cooks.distance.reg_fit_full. <= cutoff, ]), ]

reg_fit_noinfl <- lm(Z_issue.emphasis
                     ~ Previous.government
                     + Party_size
                     + Prec.Vote.share.change.2
                     + Challenger2
                     + lrecon
                     + galtan,
                     data = df2)
summary(reg_fit_noinfl)


# get robust standard errors
reg_fit_check_noinfl <- coeftest(reg_fit_noinfl, vcov = vcovHC(reg_fit_noinfl, type="HC1"))
print(reg_fit_check_noinfl)



### Robustness checks with different coding decisions ### 

df_tmp <- df
df_tmp$challenger[df_tmp$Party == "REM" & df_tmp$Year == 2017] <- 0.5
df_tmp$Previous.government[df_tmp$Party == "REM" & df_tmp$Year == 2017] <- 0.5


df_tmp$challenger[df_tmp$Party == "SC" & df_tmp$Year == 2013] <- 0.5
df_tmp$Previous.government[df_tmp$Party == "FI-PdL" & df_tmp$Year == 2013] <- 0.5
df_tmp$Previous.government[df_tmp$Party == "LN" & df_tmp$Year == 2013] <- 0.5


reg_fit_check <- lm(Z_issue.emphasis
                    ~ Previous.government
                    + Party_size
                    + Prec.Vote.share.change.2
                    + Challenger2
                    + lrecon
                    + galtan,
                    data  = df_tmp)
summary(reg_fit_check)

# get robust standard errors
reg_fit_check_rob <- coeftest(reg_fit_check, vcov = vcovHC(reg_fit_check, type="HC1"))
print(reg_fit_check_rob)




### Regressions over subsets ###

# Large countries

reg_fit_Z1s1 <- lm(Z_issue.emphasis
                   ~ Previous.government
                   + Party_size
                   + Prec.Vote.share.change.2
                   + Challenger2
                   + lrecon
                   + galtan,
                   data = df[df$Country != "Austria" & df$Country != "Ireland" & df$Country != "Portugal", ] )
summary(reg_fit_Z1s1)

# get robust standard errors
reg_fit_Z1s1_rob <- coeftest(reg_fit_Z1s1, vcov = vcovHC(reg_fit_Z1s1, type="HC1"))
print(reg_fit_Z1s1_rob)



# Small countries

reg_fit_Z1s2 <- lm(Z_issue.emphasis
                   ~ Previous.government
                   + Party_size
                   + Prec.Vote.share.change.2
                   + Challenger2
                   + lrecon
                   + galtan,
                   data = df[df$Country == "Austria" | df$Country == "Ireland" | df$Country == "Portugal", ])
summary(reg_fit_Z1s2)


# get robust standard errors
reg_fit_Z1s2_rob <- coeftest(reg_fit_Z1s2, vcov = vcovHC(reg_fit_Z1s2, type="HC1"))
print(reg_fit_Z1s2_rob)









#### Residual analysis ####

reg_fit_full <- reg_fit_Z1

# plot fitted versus observed - inspect overall fit
plot(reg_fit_full$fitted.values, df$Z_issue.emphasis, pch = 16, cex = 0.6)

# Get largest residuals
res.frame <- (data.frame(df$Party, df$Year, reg_fit_full$residuals) )
res.frame[order(abs(res.frame$reg_fit_full.residuals ) ), ]


# Get those cases with residuals above 1.5 Standard deviations
df$ID[ abs(reg_fit_full$residuals) > 1.5*sd(reg_fit_full$residuals) ]

df$Party_sel_name <- NA
df$Party_sel_name[ abs(reg_fit_full$residuals) > 1.5*sd(reg_fit_full$residuals) & abs(df$Z_issue.emphasis) > sd(df$Z_issue.emphasis) ] <- as.character(df$ID[ abs(reg_fit_full$residuals) > 1.5*sd(reg_fit_full$residuals) & abs(df$Z_issue.emphasis) > sd(df$Z_issue.emphasis) ])
df$fit.class <- 0

df$fit.class[ abs(reg_fit_full$residuals) > 1.5*sd(reg_fit_full$residuals) & abs(df$Z_issue.emphasis) > sd(df$Z_issue.emphasis) ]<- 1




# Get those cases with residuals below 0.5 Standard deviations
pred.frame <- data.frame( predict(reg_fit_full, newdata = df, interval = 'confidence') )

selector <- df$ID[df$Z_issue.emphasis > pred.frame$lwr & df$Z_issue.emphasis < pred.frame$upr & abs(df$Z_issue.emphasis) > sd(df$Z_issue.emphasis) ]


df$Party_sel_name[df$ID %in% selector] <- as.character( df$ID[df$ID %in% selector] )
df$fit.class[df$ID %in% selector] <- 2


# declare positions for case labels
df$pos_values <- 3

df$pos_values[df$ID == "PT_CDU_2011"] <- 2   
df$pos_values[df$ID == "PT_CDU_2015"] <- 2   
df$pos_values[df$ID == "AT_Gruene_2013"] <- 2
df$pos_values[df$ID == "DE_FDP_2017"] <- 2
df$pos_values[df$ID == "IT_M5S_2013"] <- 4
df$pos_values[df$ID == "IT_FI-PdL_2018"] <- 1
df$pos_values[df$ID == "DE_Green Party_2013"] <- 4

df$pos_values[df$ID == "AT_TS_2013"] <- 4   
df$pos_values[df$ID == "AT_SPO_2013"] <- 1
df$pos_values[df$ID == "DE_AfD_2017"] <- 4
df$pos_values[df$ID == "UK_Lab_2010"] <- 1
df$pos_values[df$ID == "UK_UKIP_2015"] <- 2
df$pos_values[df$ID == "UK_UKIP_2010"] <- 4
df$pos_values[df$ID == "UK_Lib_2015"] <- 2
df$pos_values[df$ID == "PT_PSD_2015"] <- 2

unique(df$Party_sel_name)


# clean party labels

df$Party_sel_name <- sapply(df$Party_sel_name, function(x){gsub("_20", "_", x)})
df$Party_sel_name <- sapply(df$Party_sel_name, function(x){gsub("_SPO", "_SP", x)})
df$Party_sel_name <- sapply(df$Party_sel_name, function(x){gsub("_FPO", "_FP", x)})
df$Party_sel_name <- sapply(df$Party_sel_name, function(x){gsub("_Gruene", "_Green", x)})
df$Party_sel_name <- sapply(df$Party_sel_name, function(x){gsub("_Green Party", "_Green", x)})


# make the plot
plot(reg_fit_full$fitted.values, df$Z_issue.emphasis,
     col = c("grey80", "grey30", "grey30")[as.factor(df$fit.class)], 
     pch = c(16, 2, 16)[as.factor(df$fit.class)],
     xlab = "Fitted values",
     ylab = "Observed values",
     xlim = c(-1.7, 1.7),
     ylim = c(-1.7, 1.7))
abline(lm(df$Z_issue.emphasis ~ reg_fit_full$fitted.values), col = "grey 50" )
text(reg_fit_full$fitted.values, df$Z_issue.emphasis, 
     labels=df$Party_sel_name,  cex= 0.5, offset = 0.4, 
     col = c("grey80", "grey30", "black")[as.factor(df$fit.class)],
     pos = df$pos_values)
legend("topleft", pch=c(2, 16)[(c(1,2))], c( "bad fit", "good fit"), bty="n",  cex=.6)








